@@ -20,6 +20,7 @@
 #include <FL/fl_string_functions.h>  // fl_strdup
 #include <FL/platform.H>
 #include "../../flstring.h"
+#include "../../Fl_Timeout.h"
 
 #include <X11/Xlib.h>
 #include <locale.h>
@@ -454,42 +455,84 @@ void Fl_X11_System_Driver::newUUID(char *uuidBuffer)
 /*
  Note: `prefs` can be NULL!
  */
-char *Fl_X11_System_Driver::preference_rootnode(Fl_Preferences * /*prefs*/, Fl_Preferences::Root root, const char *vendor,
+char *Fl_X11_System_Driver::preference_rootnode(Fl_Preferences * /*prefs*/,
+                                                Fl_Preferences::Root root,
+                                                const char *vendor,
                                                 const char *application)
 {
   static char *filename = 0L;
   if (!filename) filename = (char*)::calloc(1, FL_PATH_MAX);
-  const char *e;
-  switch (root&Fl_Preferences::ROOT_MASK) {
+  const char *home = "";
+  int pref_type = root & Fl_Preferences::ROOT_MASK;
+  switch (pref_type) {
     case Fl_Preferences::USER:
-      e = getenv("HOME");
+      home = getenv("HOME");
       // make sure that $HOME is set to an existing directory
-      if ( (e==0L) || (e[0]==0) || (::access(e, F_OK)==-1) ) {
+      if ((home == NULL) || (home[0] == 0) || (::access(home, F_OK) == -1)) {
         struct passwd *pw = getpwuid(getuid());
-        e = pw->pw_dir;
-      }
-      if ( (e==0L) || (e[0]==0) || (::access(e, F_OK)==-1) ) {
-        return 0L;
-      } else {
-        strlcpy(filename, e, FL_PATH_MAX);
-        if (filename[strlen(filename)-1] != '/')
-          strlcat(filename, "/", FL_PATH_MAX);
-        strlcat(filename, ".fltk/", FL_PATH_MAX);
+        if (pw)
+          home = pw->pw_dir;
       }
+      if ((home == 0L) || (home[0] == 0) || (::access(home, F_OK) == -1))
+        return NULL;
+      strlcpy(filename, home, FL_PATH_MAX);
+      if (filename[strlen(filename) - 1] != '/')
+        strlcat(filename, "/", FL_PATH_MAX);
+      strlcat(filename, ".fltk/", FL_PATH_MAX);
       break;
     case Fl_Preferences::SYSTEM:
       strcpy(filename, "/etc/fltk/");
       break;
+    default:              // MEMORY
+      filename[0] = '\0'; // empty string
+      break;
   }
 
   // Make sure that the parameters are not NULL
-  if ( (vendor==0L) || (vendor[0]==0) )
+  if ( (vendor==NULL) || (vendor[0]==0) )
     vendor = "unknown";
-  if ( (application==0L) || (application[0]==0) )
+  if ( (application==NULL) || (application[0]==0) )
     application = "unknown";
 
   snprintf(filename + strlen(filename), FL_PATH_MAX - strlen(filename),
            "%s/%s.prefs", vendor, application);
+
+  // If this is not the USER path (i.e. SYSTEM or MEMORY), we are done
+  if ((pref_type) != Fl_Preferences::USER)
+    return filename;
+
+  // If the legacy file exists, we are also done
+  if (::access(filename, F_OK)==0)
+    return filename;
+
+  // This is USER mode, and there is no legacy file. Create an XDG conforming path.
+  // Check $XDG_CONFIG_HOME, and if it isn't set, default to $HOME/.config
+  const char *xdg = getenv("XDG_CONFIG_HOME");
+  if (xdg==NULL) {
+    xdg = "~/.config";
+  }
+  filename[0] = 0;
+  if (strncmp(xdg, "~/", 2)==0) {
+    strlcpy(filename, home, FL_PATH_MAX);
+    strlcat(filename, "/", FL_PATH_MAX);
+    strlcat(filename, xdg+2, FL_PATH_MAX);
+  } else if (strncmp(xdg, "$HOME/", 6)==0) {
+    strlcpy(filename, home, FL_PATH_MAX);
+    strlcat(filename, "/", FL_PATH_MAX);
+    strlcat(filename, xdg+6, FL_PATH_MAX);
+  } else if (strncmp(xdg, "${HOME}/", 8)==0) {
+    strlcpy(filename, home, FL_PATH_MAX);
+    strlcat(filename, "/", FL_PATH_MAX);
+    strlcat(filename, xdg+8, FL_PATH_MAX);
+  } else {
+    strlcpy(filename, xdg, FL_PATH_MAX);
+  }
+  strlcat(filename, "/", FL_PATH_MAX);
+  strlcat(filename, vendor, FL_PATH_MAX);
+  strlcat(filename, "/", FL_PATH_MAX);
+  strlcat(filename, application, FL_PATH_MAX);
+  strlcat(filename, ".prefs", FL_PATH_MAX);
+
   return filename;
 }
 
@@ -657,4 +700,30 @@ void Fl_X11_System_Driver::own_colormap() {
 #endif // USE_COLORMAP
 }
 
+int Fl_X11_System_Driver::ready() {
+  Fl_Timeout::elapse_timeouts();
+  if (Fl_Timeout::time_to_wait(1.0) <= 0.0) return 1;
+  return this->poll_or_select();
+}
+
+double Fl_X11_System_Driver::wait(double time_to_wait)
+{
+  if (time_to_wait <= 0.0) {
+    // do flush second so that the results of events are visible:
+    int ret = this->poll_or_select_with_delay(0.0);
+    Fl::flush();
+    return ret;
+  } else {
+    // do flush first so that user sees the display:
+    Fl::flush();
+    if (Fl::idle) // 'idle' may have been set within flush()
+      time_to_wait = 0.0;
+    else {
+      Fl_Timeout::elapse_timeouts();
+      time_to_wait = Fl_Timeout::time_to_wait(time_to_wait);
+    }
+    return this->poll_or_select_with_delay(time_to_wait);
+  }
+}
+
 #endif // !defined(FL_DOXYGEN)
