@@ -129,6 +129,12 @@ int Fl_Menu_Item_children(const Fl_Menu_Item *self);
 
 const Fl_Menu_Item *Fl_Menu_Item_at(const Fl_Menu_Item *self, int idx);
 
+int Fl_Menu_Item_add(Fl_Menu_Item *self, const char *name, int shortcut, Fl_Callback *cb,
+                     void *data, int flag);
+
+int Fl_Menu_Item_insert(Fl_Menu_Item *self, int index, const char *name, int shortcut,
+                        Fl_Callback *cb, void *data, int flag);
+
 void Fl_mac_set_about(Fl_Callback *cb, void *user_data, int shortcut);
 
 #ifdef __cplusplus
