@@ -1,6 +1,6 @@
 #import <Cocoa/Cocoa.h>
 
-void setWindowTransparency(void *xid, unsigned char val) {
+void cfltk_setWindowTransparency(void *xid, unsigned char val) {
     NSWindow *win = (NSWindow *)xid;
     CGFloat alpha = ((CGFloat)val)/255.0;
     [win setAlphaValue:alpha];
@@ -8,12 +8,12 @@ void setWindowTransparency(void *xid, unsigned char val) {
     [win setOpaque:NO];
 }
 
-NSView *my_getContentView(void *xid) {
+NSView *cfltk_getContentView(void *xid) {
     NSWindow *win = (NSWindow *)xid;
     return [win contentView];
 }
 
-double my_getScalingFactor(void *xid) {
+double cfltk_getScalingFactor(void *xid) {
     NSWindow *win = (NSWindow *)xid;
     NSView *view = [win contentView];
     NSSize s = [view convertSizeToBacking:NSMakeSize(10, 10)];
@@ -21,13 +21,13 @@ double my_getScalingFactor(void *xid) {
     return (double)scale;
 }
 
-void my_winShow(void *xid) {
+void cfltk_winShow(void *xid) {
     NSWindow *win = (NSWindow *)xid;
     [win makeKeyAndOrderFront:win];
     [NSApp activateIgnoringOtherApps:YES];
 }
 
-void my_winHide(void *xid) {
+void cfltk_winHide(void *xid) {
     NSWindow *win = (NSWindow *)xid;
     [win orderOut:win];
 }
\ No newline at end of file
